netapp_ontap.models.firmware API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.firmware`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class FirmwareSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the Firmware object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `cluster_fw_progress: List[FirmwareUpdateProgress] GET`

    The cluster_fw_progress field of the firmware.

  `disk: FirmwareDisk GET`

    The disk field of the firmware.

  `dqp: FirmwareDqp GET`

    The dqp field of the firmware.

  `shelf: FirmwareShelf GET`

    The shelf field of the firmware.

  `sp_bmc: FirmwareSpBmc GET`

    The sp_bmc field of the firmware.

  `system_firmware: SystemFirmware GET`

    The system_firmware field of the firmware.